package framework.persistence;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.AnnotationConfiguration;

/**
 * @uml.dependency   supplier="framework.persistence.MockSession"
 * @uml.dependency   supplier="org.hibernate.SessionFactory"
 * @uml.dependency   supplier="framework.persistence.MockSessionFactory"
 */
public class PersistenceUtil {
    /** Location of persistence properties file. */
    public static final String PERSISTENCE_PROPERTIES = "/persistence.properties";
    
    /** defines the SessionFactory to use */
    public static final String PERSISTENCE_FACTORY = "persistence.factory";
    public static final String PERSISTENCE_FACTORY_HIBERNATE = "hibernate";
    public static final String PERSISTENCE_FACTORY_MOCK = "mock";

    private static final SessionFactory sessionFactory;

    static {
        Log log = LogFactory.getLog(PersistenceUtil.class);
        
        try {
            Properties props = new Properties();
            props.load(PersistenceUtil.class.getResourceAsStream(PERSISTENCE_PROPERTIES));
            String factory = props.getProperty(PERSISTENCE_FACTORY);

            if (factory != null && factory.trim().equals(PERSISTENCE_FACTORY_MOCK)) {
                sessionFactory = MockSessionFactory.getInstance();
            } else {
                // By default (and when the property has the "mock" value) we
                // use the Hibernate SessionFactory
                
                // Create the SessionFactory from hibernate.cfg.xml
                sessionFactory = new AnnotationConfiguration().configure().buildSessionFactory();
            }
        } catch (Throwable ex) {
            // Make sure you log the exception, as it might be swallowed
            log.error("Initial SessionFactory creation failed.", ex);
            throw new ExceptionInInitializerError(ex);
        }
    }

    public static SessionFactory getSessionFactory() {
        return sessionFactory;
    }

}
