package framework.service;

import framework.domain.DomainException;
import framework.exception.ServiceException;
import framework.view.View;

abstract class Service<R> {
    protected TransactionManager txManager;
    protected R returnValue;

    public Service() {
        this.txManager = TransactionManagerFactory.getLocalTransactionManager();
    }
    
    public final R execute() throws DomainException, ServiceException {
	Transaction tx = null;
        boolean txCommited = false;

        try {
            tx = txManager.newTransaction();
            tx.begin();
            before();
            returnValue = action();
            after();
            tx.commit();
            txCommited = true;
            return returnValue;
        } finally {
            if (!txCommited && tx != null) { tx.rollback(); }
        }
        
    }
    
    protected abstract void before() throws DomainException;
    protected abstract R action() throws DomainException;
    protected abstract void after() throws DomainException;
    
}
